"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Overlay = Overlay;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _index = require("./index");

var _context = require("./context");

var _hooks = require("../hooks");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// This is iOS/Android only implementation. Refer Overlay.web.tsx for Web implementation
function Overlay(props) {
  const {
    isOpen,
    children,
    onClose,
    focusable = true,
    animated = true,
    mode = 'single',
    animationEntryDuration,
    animationExitDuration,
    onRequestClose
  } = props;
  const {
    styles,
    isExited
  } = (0, _hooks.useAnimatedStyles)({
    animated,
    animationEntryDuration,
    animationExitDuration,
    isOpen
  });
  (0, _react.useEffect)(() => {
    const backHandler = _reactNative.BackHandler.addEventListener('hardwareBackPress', function closePopover() {
      if (typeof onRequestClose === 'function' && isOpen) {
        onRequestClose();
        return true;
      }

      return false;
    });

    return () => backHandler.remove();
  }, [onRequestClose, isOpen]);

  if (!isOpen && isExited) {
    return null;
  } // If focusable we render it in RN modal so it shifts accessibility focus


  const content = focusable && mode === 'single' ? /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    visible: true,
    transparent: true,
    onRequestClose: onRequestClose
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [_reactNative.StyleSheet.absoluteFill, styles],
    pointerEvents: "box-none"
  }, /*#__PURE__*/_react.default.createElement(_context.OverlayContext.Provider, {
    value: {
      onClose
    }
  }, children))) : /*#__PURE__*/_react.default.createElement(_index.OverlayContainer, null, /*#__PURE__*/_react.default.createElement(_reactNative.Animated.View, {
    style: [_reactNative.StyleSheet.absoluteFill, styles, {
      marginTop: _reactNative.StatusBar.currentHeight
    }],
    pointerEvents: "box-none"
  }, /*#__PURE__*/_react.default.createElement(_context.OverlayContext.Provider, {
    value: {
      onClose
    }
  }, children)));
  return content;
}
//# sourceMappingURL=Overlay.js.map