function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { Overlay } from '../Overlay/Overlay';
import { useControllableState, useOn, usePopover } from '../hooks';
import { Popper } from '../Popper/Popper';
import { OverlayBackdrop } from '../Overlay/OverlayBackdrop';

const Popover = props => {
  var _props$focusable;

  let triggerRef = React.useRef(null);
  let [overlayRef, setOverlayRef] = React.useState({
    current: null
  });
  const [isOpen, setIsOpen] = useControllableState({
    defaultValue: props.defaultIsOpen,
    value: props.isOpen,
    onChange: props.onOpenChange
  });

  const handleOpen = () => {
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
  };

  const isTriggerElement = /*#__PURE__*/React.isValidElement(props.trigger);
  const isTriggerRef = props.trigger.hasOwnProperty('current');

  if (!isTriggerElement && !isTriggerRef) {
    console.warn(`Popover: Invalid 'trigger' prop received, please pass a valid ReactElement or a Ref`);
  } // @ts-ignore - We already checked isValidElement above.


  const triggerExistingProps = isTriggerElement ? props.trigger.props : {};
  const handlers = useOn({
    on: props.on,
    onClose: handleClose,
    onOpen: handleOpen,
    overlayRef,
    ...triggerExistingProps
  });
  let triggerElem = null;

  if (isTriggerRef) {
    // @ts-ignore
    triggerRef = props.trigger;
  } else if (isTriggerElement) {
    // @ts-ignore - We already checked isValidElement above.
    triggerElem = /*#__PURE__*/React.cloneElement(props.trigger, {
      ref: triggerRef,
      ...handlers
    });
  } // ARIA props


  const {
    triggerProps,
    contentProps
  } = usePopover({
    isOpen,
    disableAriaAttributes: props.disableAriaAttributes
  });

  if (triggerElem) {
    triggerElem = /*#__PURE__*/React.cloneElement(triggerElem, { ...triggerProps
    });
  } // If trigger is hover, we shouldn't shift user's focus


  const isFocusabe = props.on !== 'hover';
  return /*#__PURE__*/React.createElement(React.Fragment, null, triggerElem, /*#__PURE__*/React.createElement(Overlay, {
    isOpen: isOpen,
    onClose: handleClose,
    isKeyboardDismissable: props.isKeyboardDismissable,
    focusable: (_props$focusable = props.focusable) !== null && _props$focusable !== void 0 ? _props$focusable : isFocusabe,
    animated: props.animated,
    mode: props.mode,
    animationEntryDuration: props.animationEntryDuration,
    animationExitDuration: props.animationExitDuration,
    overlayRef: overlayRef,
    triggerRef: triggerRef,
    shouldCloseOnOutsideClick: props.shouldCloseOnOutsideClick,
    onRequestClose: props.onRequestClose
  }, /*#__PURE__*/React.createElement(Popper, _extends({}, props, {
    onClose: handleClose,
    triggerRef: triggerRef,
    contentProps: contentProps,
    setOverlayRef: setOverlayRef
  }))));
};

Popover.Content = Popper.Content;
Popover.Arrow = Popper.Arrow;
Popover.Backdrop = OverlayBackdrop;
export { Popover };
//# sourceMappingURL=Popover.js.map